@@ -18,11 +18,17 @@ class ArgUtils:
     def getString(name, defaultvalue):  # @NoSelf
         for i in range(len(sys.argv)):
             if sys.argv[i] == "--" + name or sys.argv[i] == "-" + name:
-                return sys.argv[i + 1].strip()
+                return sys.argv[i + 1].strip() if i + 1 < len(sys.argv) else defaultvalue
         return defaultvalue
     
     def isArgPresent(name):  # @NoSelf
         for i in range(len(sys.argv)):
             if sys.argv[i] == "--" + name or sys.argv[i] == "-" + name:
                 return True
-        return False
\ No newline at end of file
+        return False
+    
+    def getArgsCount():  # @NoSelf
+        return len(sys.argv)
+    
+    def getArg(idx):  # @NoSelf
+        return sys.argv[idx]
\ No newline at end of file
